function piechart(selector, data, category) {
  // Set up the SVG element
  var svg = d3
    .select(selector)
    .append("svg")
    .attr("width", 500)
    .attr("height", 500);

  // Group data by category and count the number of occurrences
  var counts = d3.rollup(
    data,
    (v) => v.length,
    (d) => d[category]
  );

  // Convert counts to an array of objects with "category" and "count" properties
  var countsArray = Array.from(counts, ([category, count]) => ({
    category,
    count,
  }));

  // Define color scale for categories
  var color = d3
    .scaleOrdinal()
    .domain(countsArray.map((d) => d.category))
    .range(d3.schemeCategory10);

  // Define arc generator
  var arc = d3.arc().innerRadius(0).outerRadius(200);

  // Define pie generator
  var pie = d3.pie().value((d) => d.count);

  // Generate pie chart data
  var pieData = pie(countsArray);

  // Add slices for each category
  svg
    .selectAll("path")
    .data(pieData)
    .enter()
    .append("path")
    .attr("d", arc)
    .attr("fill", (d) => color(d.data.category))
    .attr("transform", "translate(250,250)");

  // Add legend for categories
  var legend = svg
    .selectAll(".legend")
    .data(pieData)
    .enter()
    .append("g")
    .attr("class", "legend")
    .attr("transform", (d, i) => "translate(" + (350 + i * 50) + ", 100)");

  legend
    .append("rect")
    .attr("x", 0)
    .attr("y", 0)
    .attr("width", 20)
    .attr("height", 20)
    .attr("fill", (d) => color(d.data.category));

  legend
    .append("text")
    .attr("x", 30)
    .attr("y", 10)
    .text((d) => d.data.category + " (" + d.data.count + ")");
}
